/* Lighting vertex shader */

void DirectionalLight(in int i, in vec3 normal, inout vec4 ambient, inout vec4 diffuse, inout vec4 specular)
{
	float nDotVP;	// normal . light direction
	float nDotHV;	// normal . light half vector
	float pf;		// power factor

	// TODO: Compute diffuse angle
	nDotVP = max(0.0, dot(normal,normalize(vec3(gl_LightSource[i].position))));

	// TODO: Compute specular angle
	nDotHV = max(0.0, dot(normal,vec3(gl_LightSource[i].halfVector)));

	// TODO: Apply shininess factor
	if (nDotVP == 0.0)
	{
		pf = 0.0;
	}
	else
	{
		pf = pow(nDotHV, gl_FrontMaterial.shininess);
	}

	// TODO: Accumulate components
	ambient += gl_LightSource[i].ambient;
	diffuse += gl_LightSource[i].diffuse * nDotVP;
	specular += gl_LightSource[i].specular * pf;
}

void main()
{
	// Lighting accumulators
	vec4 amb = vec4(0.0);
	vec4 diff = vec4(0.0);
	vec4 spec = vec4(0.0);
	vec3 normal = vec3(0.0);

	int NumEnabledLights = 1;

	// Compute transformed vertex position
	gl_Position = gl_ModelViewProjectionMatrix*gl_Vertex;


	// TODO: Compute transformed (normalized) normal
	normal = normalize(gl_NormalMatrix * gl_Normal);

	// Loop through light sources
	for (int i = 0; i < NumEnabledLights; i++)
	{
		if (gl_LightSource[i].position.w == 0.0)
		{
			DirectionalLight(i, normal, amb, diff, spec);
		}
	}

	// TODO: Compute final lighting color
	gl_FrontColor = amb*gl_FrontMaterial.ambient + diff*gl_FrontMaterial.diffuse + spec*gl_FrontMaterial.specular;
}
